@@ -2,7 +2,7 @@ package Test::Stream;
 use strict;
 use warnings;
 
-our $VERSION = '1.301001_075';
+our $VERSION = '1.301001_090';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 use Test::Stream::Context qw/context/;
@@ -389,7 +389,8 @@ sub done_testing {
         return;
     }
 
-    if ($self->[FOLLOW_UPS]) {
+    # Do not run followups in subtest!
+    if ($self->[FOLLOW_UPS] && !@{$self->[SUBTESTS]}) {
         $_->($ctx) for @{$self->[FOLLOW_UPS]};
     }
 
@@ -488,10 +489,6 @@ sub _update_state {
         }
     }
     elsif (!$self->[NO_HEADER] && $e->isa('Test::Stream::Event::Finish')) {
-        if ($self->[FOLLOW_UPS]) {
-            $_->($e->context) for @{$self->[FOLLOW_UPS]};
-        }
-
         $state->[STATE_ENDED] = $e->context->snapshot;
 
         my $plan = $state->[STATE_PLAN];
@@ -540,7 +537,7 @@ sub _process_event {
     my ($self, $e, $cache) = @_;
 
     if ($self->[MUNGERS]) {
-        $_->($self, $e) for @{$self->[MUNGERS]};
+        $_->($self, $e, $e->subevents) for @{$self->[MUNGERS]};
     }
 
     $self->_render_tap($cache) unless $cache->{no_out};
@@ -577,6 +574,18 @@ sub _render_tap {
     }
 }
 
+sub _scan_for_begin {
+    my ($stop_at) = @_;
+    my $level = 2;
+
+    while (my @call = caller($level++)) {
+        return 1 if $call[3] =~ m/::BEGIN$/;
+        return 0 if $call[3] eq $stop_at;
+    }
+
+    return undef;
+}
+
 sub _finalize_event {
     my ($self, $e, $cache) = @_;
 
@@ -587,7 +596,27 @@ sub _finalize_event {
 
         $self->[SUBTEST_EXCEPTION]->[-1] = $e if $e->in_subtest;
 
-        die $e if $e->in_subtest || !$self->[EXIT_ON_DISRUPTION];
+        if ($e->in_subtest) {
+            my $begin = _scan_for_begin('Test::Stream::Subtest::subtest');
+
+            if ($begin) {
+                warn "SKIP_ALL in subtest via 'BEGIN' or 'use', using exception for flow control\n";
+                die $e;
+            }
+            elsif(defined $begin) {
+                no warnings 'exiting';
+                eval { last TEST_STREAM_SUBTEST };
+                warn "SKIP_ALL in subtest flow control error: $@";
+                warn "Falling back to using an exception.\n";
+                die $e;
+            }
+            else {
+                warn "SKIP_ALL in subtest could not find flow-control label, using exception for flow control\n";
+                die $e;
+            }
+        }
+
+        die $e unless $self->[EXIT_ON_DISRUPTION];
         exit 0;
     }
     elsif (!$cache->{do_tap} && $e->isa('Test::Stream::Event::Bail')) {
@@ -596,7 +625,27 @@ sub _finalize_event {
 
         $self->[SUBTEST_EXCEPTION]->[-1] = $e if $e->in_subtest;
 
-        die $e if $e->in_subtest || !$self->[EXIT_ON_DISRUPTION];
+        if ($e->in_subtest) {
+            my $begin = _scan_for_begin('Test::Stream::Subtest::subtest');
+
+            if ($begin) {
+                warn "BAILOUT in subtest via 'BEGIN' or 'use', using exception for flow control.\n";
+                die $e;
+            }
+            elsif(defined $begin) {
+                no warnings 'exiting';
+                eval { last TEST_STREAM_SUBTEST };
+                warn "BAILOUT in subtest flow control error: $@";
+                warn "Falling back to using an exception.\n";
+                die $e;
+            }
+            else {
+                warn "BAILOUT in subtest could not find flow-control label, using exception for flow control.\n";
+                die $e;
+            }
+        }
+
+        die $e unless $self->[EXIT_ON_DISRUPTION];
         exit 255;
     }
 }
